function [var,var_err,pres,time] = apply_gem(ies_map,z)

%*********
% apply_gem.m
% aha:/work/jbook/asuka/GEM
% written by Jeff Book in 1998
% Program to produce time series of vertical profiles of temperature
% or specific-volume anomaly (svan) based on IES data and a precalculated
% GEM.

% ies_map indicates which IES the time series is being calculated
% for (with 9 referring to IES8, 1-4 referring to IES1-4, 5-6 referring
% to IES6-7, and 7-8 referring to IES9-10).
% z is a string indicating if a temperature or svan GEM should
% be calculated ('s' for svan, 't' for temperature)

% var is the time series of vertical profiles
% var_error is the error bar estimates for this time series
% pres is the pressure vector for the rows of var and var_error
% time is the time vector for the columns of var and var_error 

% calibrate_ies loads all the IES data and transforms them to 
% measurements of tau_800 for use with the GEM.  The outputs
% from calibrate_ies are tau_ies and tau8_ies.  tau_ies has
% rows corresonding to time (iess(:,1)) and columns corresponding
% to IES numbers [1 2 3 4 6 7 9 10].  tau8_ies corresponds to
% IES8 with rows corresponding to time (ies8(:,1)).  Both
% variables are in units of seconds.

calibrate_ies

% taufit contains the tau SLACTS curve.
% The appropriate seasonal signal is removed from the tau_800
% time series from calibrate_ies that corresponds to the chosen
% ies_map.

load taufit
year = 365.2422;
time2 = jmod(iess(:,1),year);
seasonal_tau = interp1(yd_w,taufit_w,time2);

if ies_map == 9
	time = ies8(:,1);
	time3 = jmod(ies8(:,1),year);
	seasonal_tau = interp1(yd_w,taufit_w,time3);
	tau = tau8_ies - seasonal_tau;
else
	time = iess(:,1);
	tau = tau_ies(:,ies_map) - seasonal_tau;
end

% tau is now the SLACTS corrected time series of tau_800 for the
% appropriate IES.

% The pressure vector is set up

pres = [25:25:5000];

% The appropriate GEM is loaded based on the value of z

if z == 's'
	load svan_gem
	SMF_var = SMF_svan;
	vars_w = ds_w;
else
	load temp_gem
	SMF_var = SMF_temperature;
	vars_w = Ts_w;
end

% The temperature or svan profiles are found for the IES by using
% the GEM with the tau_800 time series

var=interp2(taurange,presrange,SMF_var,tau,pres);
var_err = interp2(errtaubin,errpresbin,rmsgridabs,tau,pres);

deltap = 25;
epsilon = 1e-6;

% The GEM has no SLACTS component, but the actual temperature
% or svan profiles would have a SLACTS component based on the
% yearday of the measurement.  This SLACTS component is 
% constructed from the appropriate SLACTS curve and added into
% the profile time series at the appropriate pressure levels.
% Npres_lv is the number of pressure levels containing a SLACTS
% component.

Npres_lv = length(vars_w(1,:)); 

for lvl = 1:Npres_lv
	index(:,lvl) = find(abs(pres - lvl.*deltap) < epsilon);
	if ies_map == 9
		var(index(:,lvl),:) = var(index(:,lvl),:) + ...
interp1(yd_w,vars_w(:,lvl),time3)';
	else
		var(index(:,lvl),:) = var(index(:,lvl),:) + ...
interp1(yd_w,vars_w(:,lvl),time2)';
	end
end		 