% calibrate_ies.m
% aha:/work/jbook/asuka/GEM
% written by Jeff Book in 1998
% This program converts IES data in the form of tau_p'
% (p = bottom pressure, ' = fluctuations) to tau_800.  The data
% are transformed to tau_800' using conversions calculated by
% transform_tt_800.m and saved in slopes.mat.  The tau_800'
% are converted to tau_800 by adding in an appropriate mean
% calculated from hydrography.  The outputs from this program
% are tau_ies and tau8_ies.

% The IES data are loaded

% 5 day or 2 day filtering

%load /work/asuka/iess/Jeff_chk_filter/iess.dhcm5d
%load /work/asuka/iess/Jeff_chk_filter/ies8.dhcm5d
load iess.dhcm5d
load ies8.dhcm5d

%load /work/asuka/iess/Jeff_chk_filter/iess.dhcm2d
%load /work/asuka/iess/Jeff_chk_filter/ies8.dhcm2d

% The Conversion factors between pressure levels are loaded
% The vector s is (tau_800/tau_p) for IES1-10 (no IES5).
% The hydrographic data that occur close to IES's (10 km) and during
% good data periods are loaded.  For IES number (?) the data are
% stored as ctd_8_?.  These matrixes have one row per cast, with
% columns organized in the same way as ies_tt_cor.dat (see ctd_other_info.f)
% The relevant columns for this program are column 1 with tau_800 (s)
% data and column 2 with time (yearday 1994) data    

load slopes

% 5 day or 2 day filtering

%load ../ctd/ctd_final
load ctd_final

%load ../ctd/ctd_final_2dfilter

% The IES data are forced to have zero mean

iess(:,2:9) = iess(:,2:9) - ones(length(iess(:,2)),1)*mean(iess(:,2:9));
ies8(:,2) = ies8(:,2) - mean(ies8(:,2));

% The URI IES's are converted.  iesnum keeps track of the IES number
% being coverted (?), while snum is the appropriate index for the
% vector s for that IES.

iesnum = [1 2 3 4 6 7 9 10 8];
snum = [1 2 3 4 5 6 8 9];
for loop = 1:8

	% The IES data is converted from tau_p' to tau_800'

	iess(:,loop+1) = iess(:,loop+1).*s(snum(loop));

	% The IES data occuring at the same times as hydrographic
	% casts in the same loacation are found.  The mean of these interpolated
	% points is saved as m_ies

	eval(['ctd = ctd_8_' int2str(iesnum(loop)) ';'])
	ies_sub = interp1(iess(:,1),iess(:,loop+1),ctd(:,2));
	m_ies = mean(ies_sub);

	% The mean of the hydrographic casts near this IES is
	% saved as mctd

	mctd(loop) = mean(ctd(:,1));

	% The tau_800' data are converted to tau_800 by adding
	% in a mean such that the mean of the IES data interpolated at
	% hydrographic times agrees with the mean of the hydrographic data

	add_ies(loop) = mean(ctd(:,1)) - m_ies;
	tau_ies(:,loop) = iess(:,loop+1) + add_ies(loop);

end

% IES8 is converted from tau_p' to tau_800

ies8(:,2) = ies8(:,2).*s(7);
ies_sub = interp1(ies8(:,1),ies8(:,2),ctd_8_8(:,2));
m_ies = mean(ies_sub);
mctd(9) = mean(ctd_8_8(:,1));
add_ies(9) = mean(ctd_8_8(:,1)) - m_ies;
tau8_ies = ies8(:,2) + add_ies(9);

% The outputs from this program are tau_ies and tau8_ies both
% tau_800 (s) data.  tau_ies is a matrix with rows corresponding to
% time (iess(:,1) yearday 1994) and columns corresponding to
% IES numbers [1 2 3 4 6 7 9 10].  tau8_ies is a row vector containing
% the data for IES8 with rows corresponding to time (ies8(:,1) yearday 1994) 
	










