%
%               FILE DESCRIBING THE INDIAN OCEAN PSEUDOSTRESS 
%                      FROM COAPS ANALYSIS OF NSCAT DATA 

% The preceeding blank line is important for cvs.
% $Id: fsun3.m,v 1.2 1999/10/27 21:09:31 root Exp $
%

% $Log: fsun3.m,v $
% Revision 1.2  1999/10/27 21:09:31  root
% *** empty log message ***
%
% Revision 1.4  1999/09/21 13:50:53  paul
% changing catalog server to maewest...pdh
%
% Revision 1.3  1999/06/01 06:48:41  dbyrne
%
%
% updating things ...
%
% Revision 1.2  1999/05/21 17:46:22  paul
%  add DepthUnits = '';  .....  phemenway
%
% Revision 1.1  1999/05/21 16:55:50  paul
% Initial version....phemenway
%

% FUNCTIONS -- REQUIRED
GetFunctionName = 'getrectg';

% FUNCTIONS -- OPTIONAL
URL_m_File = 'fsun3u';
Cat_m_File = 'fsun3c';

% VARIABLES -- OPTIONAL
Server = ...
   'http://www.coaps.fsu.edu/cgi-bin/nph-nc/nscat/data/nc_gcvndn/';
%CatalogServer = ...
%  'http://koko.gso.uri.edu/cgi-bin/nph-ff/servers/nscat/fsu/fsu_nscat3fs.dat';
 CatalogServer = ...
  'http://maewest.gso.uri.edu/cgi-bin/nph-ff/catalog/fsunscat/fsu_nscat3fs.dat';

Nlon = 100;
Nlat = 64;
IntervalTime = 24.0;
MidTime = 12.0;

% VARIABLES -- REQUIRED
LonRange = [25.0 125.0];
LatRange = [-35.0 29.0];
TimeRange = [1996+275/366 1997+176/365];
DepthRange = [0 0];
Resolution = 111.0;
DepthUnits = '';

DataName = 'Wind - Indian Ocean daily pseudo-stress - COAPS(FSU)';
LongitudeName = 'lon';
LatitudeName = 'lat';
TimeName = '';
DepthName = '';
SelectableVariables = str2mat('U_Wind_Pseudostress','V_Wind_Pseudostress');
DodsName = str2mat('wind_u','wind_v');
% note: DataNull is applied *before* scaling
DataNull = [nan nan nan nan -9999 -9999];
DataScale = [0.0 1.0; 0.0 1.0; NaN NaN; NaN NaN; 0.0  1.0;  0.0  1.0];
DataRange = [NaN NaN; NaN NaN; NaN NaN; NaN NaN; NaN NaN; NaN NaN];

% COMMENTS
Comments1 = sprintf('%s\n',...
'          Indian Ocean GCV Daily Pseudo-stress from NSCAT', ...
' ', ...
' Beyond simply gridding NSCAT surface wind vectors, one usually wishes ', ...
' to avoid data voids where no NSCAT data are available. We have ', ...
' developed an objective analysis technique for producing daily  ', ...
' fields of pseudo-stress (wind component times the wind magnitude)', ...
' based only on NSCAT surface wind observations. This approach uses the', ...
' daily time-weighted fields available from COAPS as a background field,', ...
' and employs a direct minimization approach to insure NSCAT data are more', ...
' rigorously included. Tuning parameters in the approach are determined', ...
' objectively using generalized cross validation. A paper is in progress', ...
' describing the technique. The first product we have developed is for', ...
' the Indian ocean. The fields are daily, 1-degree resolution,',...
' pseudo-stress values for the region from 35S to 29N, 25E to 125E.');

Comments2 = sprintf('%s\n', ...
'    ', ...
'    Units:  (m/s)^2 ', ...
'    Time_Period_of_Content = ', ...
'         Beginning_Date:1996/275 ', ...
'         Ending_Date:1997/176 ', ...
'    Spatial_Domain = ', ...
'         Bounding Coordinates: ', ...
'              West Bounding Coordinate:25.0 ', ...
'              East Bounding Coordinate:125.0 ', ...
'              South Bounding Coordinate:-35.0 ', ...
'              North Bounding Coordinate:+29.0 ', ...
'    Point_of_Contact (Science) = ', ...
'         Address: ', ...
'            contact-name: Dr. Mark A. Bourassa', ...
'            contact-address1: Center for Ocean-Atmospheric Prediction Studies', ...
'            contact-address2: Florida State University', ...
'               contact-address3: Tallahassee, FL 32306-2840', ...
'               contact-country: USA', ...
'        contact-Telephone: (850) 644-6923', ...
'       contact-Electronic Mail Address:INTERNET > bourassa@coaps.fsu.edu', ...
'       contact-http: http://www.coaps.fsu.edu/~bourassa/', ...
'    ', ...
'    Point_of_Contact (Data Provision) = ', ...
'         Address: ', ...
'               name: Center for Ocean-Atmospheric Prediction Studies', ...
'               address1: Florida State University', ...
'               address2: Tallahassee, FL 32306-2840', ...
'               country: USA', ...
'               Telephone: (850) 644-6923', ...
'         Electronic Mail Address:INTERNET > bourassa@coaps.fsu.edu');



Comments = [Comments1 Comments2];

Acknowledge = sprintf('%s\n\n%s\n\n%s\n\n%s', ...
         ['The author of this dataset is M. A. Bourassa, bourassa@coaps.fsu.edu.'], ...
         ['The data are provided by the Center for Ocean-Atmospheric Prediction ', ...
          'Studies (COAPS), Florida State University, Tallahassee, ', ...
          'FL 32306-2840, bourassa@coaps.fsu.edu,'], ...
         ['and accessed via the Distributed Oceanographic Data ', ...
          'System (DODS: http://www.unidata.ucar.edu/packages/dods).'], ...
          ['Citation: ', ...
' A paper is in progress describing the technique.  For more information', ...
' contact Dr. Mark A. Bourassa']     );


Data_Use_Policy='';
