%
%  MET 15 minutes data from Endeavor cruises

% The preceding empty line is important
% $Log: gbemetw2.m,v $
% Revision 1.1  1999/09/02 18:33:15  root
% *** empty log message ***
%
% Revision 1.1  1999/06/01 07:10:29  dbyrne
%
%
% Moved up from kleedata/
%
% Revision 1.3  1999/05/28 22:53:04  kwoklin
% Point to new server for all jgofs datasets. Update getjgsta on loaddods.
% Fix infotext for all gb geturl files. Fix transmissivity for some gb
% files. Modify some variable names on gb files.       klee
%

% $Id: gbemetw2.m,v 1.1 1999/09/02 18:33:15 root Exp $
%  klee 03/98

GetFunctionName = 'getjgsta';

Server = 'http://maewest.gso.uri.edu/cgi-bin/nph-jg/emetw15'; %add years (19xx) afterwards
CatalogServer = nan;
Cat_m_File = 'gbemetc';
URL_m_File = 'gbbdctdu';

LonRange = [-71.42 -65.62];
LatRange = [40.20 42.37];
TimeRange = [1995.029016082 1997.933553510];
DepthRange = [-981.6 -1040.6];
Resolution = nan;

DodsName1 = str2mat('year_gmt','yrday_utc');
DodsName = str2mat('temp_air','temp_ss1','humidity','wind_speed_c','wind_dir_c');
DataName = 'MET -- MET 15 minutes data from Endeavor cruises -- WHOI/GLOBEC';     % Name for this dataset.
LongitudeName = 'lon';
LatitudeName = 'lat';
TimeName = str2mat('year_gmt','yrday_utc');        
DepthName = 'press_bar';
DepthUnits = 'millibar';
SelectableVariables = str2mat('Air_Temp','Sea_Temp','Humidity','Wind_Speed','Wind_Dir');
TextField = str2mat('EN259','EN260','EN261','EN262','EN264','EN265','EN266','EN267','EN268','EN269');
OptionalVariables = str2mat('depth_w');
SelectableOptional = str2mat('Depth_Water');

Acknowledge = [];
Data_Use_Policy = sprintf('%s' ,...
      'Any person making substantial use of a data set must communicate with the investigators who acquired the data prior to publication and anticipate that the data collectors will be co-authors of published results. This extends to model results and to data organized for retrospective studies. (Please refer to U.S. GLOBEC''s data policy Report #10 (http://cbl.umces.edu/fogarty/usglobec/reports/datapol/ datapol.contents.html).) The data available here are intended for scholarly use by the academic and scientific community, with the express understanding that any such use will properly acknowledge the originating investigator. Use or reproduction of any material herein for any commercial purpose is prohibited without prior written permission from the U.S. GLOBEC Georges Bank Data Management Office. (http://globec.whoi.edu/globec-dir/contact_dmo.html)');

%COMMENTS
Comments1 = sprintf('%s\n', ...
'                 MET 15 minutes data from Endeavor cruises ', ...
'     ', ...
'    This object contains meteorological data from several Endeavor cruises. ',...
'    ', ...
' Parameter      Description                                     Units', ...
' ---------------------------------------------------------------------------------------------', ...
' course_trim    Trimble GPS course made good                    Degrees', ...
' cruise_id      Cruise identifier                               na', ...
' day_gmt        GMT day, e.g. 22 is 22nd day on the month.      Same as day_utc', ...
' depth_cs       Chirp Sonar depth                               Meters', ...
' depth_edo      Edo water depth                                 Meters', ...
' depth_w        water depth                                     Meters', ...
' humidity       relative humidity                               Percent', ...
' lat            Latitude, south is negative                     Decimal degrees', ...
' lon            Longitude, west is negative                     Decimal degrees', ...
' month_gmt      GMT month, e.g. 6 is June.                      Same as month_utc', ...
' press_bar      barametric pressure                             Millibars', ...
' si             Scientific investigator''s name responsible for this cruise', ...
' speed_trim     Trimble GPS speed made good                     meters/second', ...
' temp_air       air temperature                                 Degrees C', ...
' temp_ss1       sea surface temperature 1 meter below the sureface   Degrees C', ...
' time_gmt       GMT time, e.g. 1315 is 1:15pm. ', ...
' wind_dir_c     wind direction (corrected for ship''s motion)   Degrees (Meteorologic convention',... 
'                                                                of"from" not "to")', ...
' wind_speed_c   wind speed (corrected for ship''s motion)       Meters/second', ...
' year_gmt       GMT year, e.g. 1997. Same as year_utc', ...
' yrday_gmt      GMT day and decimal time, e.g. 29.5 is', ...
'                January 29 at 1200', ...
'    ', ...
'The sea surface temperature as measured by the hull sensor is not shown since the sea surface ', ...
'temperature as measured via the engine inlet (field name is temp_ss1) is more accurate.');

Comments2 = sprintf('%s\n', ...
'Processing Notes',...
'    ', ...
'  1.Concatenate daily 1 minute files into one file for whole cruise ',...
'  2.Edit file for obvious bad data, i.e., missing data, garbage characters, etc. ',...
'  3.Run program which reformats data. Output parameters:',...
'     Year day, lat, long, Speed made good, course made good, gyro 1 & 2, Edo speed, Edo indicator, ',...
'     port, wind speed, starboard ws, port wind azimuth, starboard waz, air temp, relative humidity, ',...
'     baarometric pressure, sea surface temp @5m & 1m depth, Edo depth, Chirp sonar depth. ',...
'  4.Put plots of all parameters on screen and look for obvious single bad points. Edit in basic',... 
'     concatenated file. Except I have not edited depths. ',...
'  5.Iterate steps 2-4 until no more obvious bad points. ',...
'  6.Run second program which computes true wind speed and direction from speed and course made ',...
'     good, gyros, larger of port or starboard ws and accompanying wind azimuth. Outputs are year ',...
'     day, lat lon, speed and course made good, gyro, relative ws and direction, true ws and ',...
'     direction, air temp, relative humidity, barometric pressure, short- and long-wave radiation,',...
'     5m and 1m sea surface temps, Edo depth, Chirp sonar depth, Edo speed, Edo indicator. ',...
'     This file is good basic version, transmitted to Warren. Fortran Format:',...
'     (F10.5,1X,F7.4,1X.F8.4,1X,F5.2,1X.F5.1,1X,F5.1,1X,F5.2,1X,F5.1,1X,F5.2,1X,',...
'     F5.1,1X,F5.1,1X,F5.1,1X,F6.1,1X,F6.1,1X,F5.1,1X,F5.1,1X,F5.1,1X,F6.1,1X, F6.1,1X,F5.2,1X,A1). ',...
'         This is not quite true. Edo speed sometimes requires a field ] width of 6. Most files (eg,',...
'         EN282W.dat) were written as F6.2 instead of 1X, F5.2. Some files (EN278W, EN276WA & B)',...
'         have a field width of 7, so fixed width input could not be used. "Bad" files had spaces ',...
'         inserted. WJS 14 Apr 96 ',...
'     Form of file name is ENxxxW.DAT where xxx is cruise number. ',...
'  7.Check plots of true wind speed and direction to make sure they look ok.',... 
'  8.Run vector averaging program which produces 60 minute series. The program uses 60 consecutive',...
'     records and does not check for missing records. I have not carried depths since hourly averages ',...
'     do not seem useful nor Edo speeds since they seem pretty generally useless. Output parameters ',...
'     are: Year day, lat, long, true wind speed and direction, air temp, relative humidity, ',...
'     barometric pressure, short- and long-wave radiation, sea surface temp @ 5m & 1m. Output format',... 
'     is:',...
'     (F10.5,1X,F7.4,1X,F8.4,1X,F5.2,1X,F5.1,1X,F5.1,1X,F5.1,1X,F6.1,1X,F6.1,1X,',...
'     F5.1,1X,F5.1,1X,F5.1,1X).',...
'     Form of output name is: ENxxxW60.DAT where xxx is cruise number.');

Comments3 = sprintf('%s\n', ...
'Specific notes: ',...
'     ',...
'  1.Data truncated at start of concatenated file until beginning of hour ship leaves dock. ',...
'  2.',...
'     Year day 1 = January 1.',...
'     1996 - Year day computed from Trimble time.',...
'     EN276 - GLOBEC - Gap in data. File processed in two parts. A and B added to end of file name',...
'     (EN276WA.DAT)',...
'     EN278 - GLOBEC - AT bad from YD 43.12667 to 43.73373. Values set to -99.0',...
'     EN282 - GLOBEC - OK',...
'     EN283 - PRIMER - OK',...
'     EN286 - PRIMET - OK',...
'     EN288 - GLOBEC - OK',...
'     EN290 - Georges Bank - No short- or long-wave radiation. Fields set to 0.0 in files.',...
'     1977 - Year day is ship recording system value from data records. New with EN292.',...
'     EN292 - GLOBEC - OK',...
'     EN293 - Georges Slope - No Edo depth. Field set to 0.0 in files.',...
'     EN295 - PRIMER - Gap in data. File processed in two parts. A and B added',...
'     to file names (EN295WA.DAT)',...
'     EN296 - GLOBEC - OK',...
'    ', ...
'Additional summary quality notes follow:',...
'    ', ...
'Cruise Exp   Spds  Dirs    AT   RH     BP   SST  EDOZ   LWR  SWR Comments',...
'    ', ...
'EN259 GLOBEC  OK    OK    OK   >100   Good Peaks Gap',...
'EN260 GLOBEC Noisy  OK    OK    OK    Good Good  Good',...
'EN261 GLOBEC  OK   Good  Good  Noisy  Good Good  Good',...
'EN262 GLOBEC Good   OK   Good  Good   Good Spikes ---',...
'EN263 GLOBEC Not processed yet',...
'EN264 GLOBEC Good  Good  Good  Noisy  Good Good  Good',...
'EN265 GLOBEC Spikes  ?  Spikes Spikes Good Spike Bad Section',...
'EN266 GLOBEC Good  Good  Noisy Noisy  Good Spike Bad S Good  Good',...
'   ', ...
'EN264-266 RH >100',...
'   ', ...
'Output formats may be different than those stated above since some of the',...
'cruises were reprocessed.  Contact R. Payne if you need to read the ',...
'original data.');

Comments4 = sprintf('%s\n', ...
'   ', ...
'    Time_Period_of_Content = ', ...
'         Beginning_Date: Jan. 10, 1995 (1995.029016082)', ...
'         Ending_Date:    Dec. 06, 1997 (1997.933553510)', ...
'    Spatial_Domain = ', ...
'         Bounding Coordinates: ', ...
'              West Bounding Coordinate: 71.4190 W ', ...
'              East Bounding Coordinate: 65.6177 W ', ...
'              South Bounding Coordinate: 40.2875 N ', ...
'              North Bounding Coordinate: 42.3604 N ', ...
'    Units: See table above',...
'   ', ...
'    Point_of_Contact = ', ...
'         Address - si: ', ...
'               Dick Payne ', ...
'               Woods Hole Oceanography Institution ', ...
'               Woods Hole, MA 02543-1127',...
'               USA ', ...
'               Electronic Mail Address:INTERNET > rpayne@whoi.edu',...
'         Address - globec: ',...
'               Robert Groman',...
'               Swift House MS# 38',...
'               Woods Hole, MA 02543-1127',...
'               USA ',...
'               Electronic Mail Address:INTERNET > rgroman@whoi.edu',...
'               FAX: (508) 457-2169',...
'         Address - dods: ',...
'               Electronic Mail Address:INTERNET > support@unidata.ucar.edu ');

Comments = [Comments1 Comments2 Comments3 Comments4];