%
%  GLOBEC Fishing Vessel CTD Data

% The preceding empty line is important
% $Log: gbfvctd.m,v $
% Revision 1.2  1999/10/27 22:10:39  root
% Fixed many spelling and grammatical errors in comment fields.
%
% Revision 1.1  1999/09/02 18:33:17  root
% *** empty log message ***
%
% Revision 1.2  1999/07/15 20:10:20  kwoklin
% Change Oxygen to Dissolved_Oxygen.   klee
%
% Revision 1.1  1999/06/01 07:10:30  dbyrne
%
%
% Moved up from kleedata/
%
% Revision 1.3  1999/05/28 22:53:04  kwoklin
% Point to new server for all jgofs datasets. Update getjgsta on loaddods.
% Fix infotext for all gb geturl files. Fix transmissivity for some gb
% files. Modify some variable names on gb files.       klee
%

% $Id: gbfvctd.m,v 1.2 1999/10/27 22:10:39 root Exp $
%  klee 04/99

GetFunctionName = 'getjgsta';

Server = 'http://maewest.gso.uri.edu/cgi-bin/nph-jg/fvctd';  
CatalogServer = nan;
Cat_m_File = 'gbrlctdc';
URL_m_File = 'gbfvctdu';

LonRange = [-69.8 -69.5];
LatRange = [42.5 43.7];
TimeRange = [1998.13972603 1998.41643836];
DepthRange = [0 295];
Resolution = nan;

DodsName1 = str2mat('year_utc','month_utc','day_utc','time_utc');
DodsName = str2mat('temp','sal','sigma_t_ctd','potemp_ctd','fluor','light_tran',...
                   'par_d','o2','bvfq','sound_vel','station');
DataName = 'Water Column - Fishing Vessel CTD - UNH/GLOBEC ';    
LongitudeName = 'lon';
LatitudeName = 'lat';
TimeName =  str2mat('month_utc','day_utc','time_utc');        
DepthName = 'press';
DepthUnits = 'Meters';
SelectableVariables = str2mat('Sea_Temp','Salinity','Sigma_t','Pot_Temp','Fluorescence','Transmissivity',...
                              'PAR','Dissolved_Oxygen','Brunt_Vaisala_Freq','Sound_Vel');
TextField = str2mat('SC9801','SC9802',' SC9803');
OptionalVariables = str2mat('depth','depth_w','dynh_0','cond_ctd');
SelectableOptional = str2mat('Depth_Sample','Depth_Water','Dyn_Height','Conductivity');

Acknowledge = [];
Data_Use_Policy = sprintf('%s' ,...
      'Any person making substantial use of a data set must communicate with the investigators who acquired the data prior to publication and anticipate that the data collectors will be co-authors of published results. This extends to model results and to data organized for retrospective studies. (Please refer to U.S. GLOBEC''s data policy Report #10 (http://cbl.umces.edu/fogarty/usglobec/reports/datapol/ datapol.contents.html).) The data available here are intended for scholarly use by the academic and scientific community, with the express understanding that any such use will properly acknowledge the originating investigator. Use or reproduction of any material herein for any commercial purpose is prohibited without prior written permission from the U.S. GLOBEC Georges Bank Data Management Office. (http://globec.whoi.edu/globec-dir/contact_dmo.html)');

%COMMENTS
Comments1 = sprintf('%s\n', ...
'                                 Fishing Vessel CTD Data      ',...
'   ',...
'                   Parameter         Description                         Units',...
'                 ---------------------------------------------------------------',...
'   ',...
'                   cruiseid          Cruise identification- if not ''official'', month-yr used',...
'                   station           Station number                      n/a',...
'                   lat               Latitude                            decimal degrees, north positive',...
'                   lon               Longitude                           decimal degrees, east is positive',...
'                   time_utc          UTC time at bottom of cast          n/a',...
'                   day_utc           UTC day of cast                     n/a',...
'                   month_utc         UTC month                           n/a',...
'                   year_utc          UTC year                            n/a',...
'                   depth_w           Depth of bottom at station,         meters',...
'                                     estimated from fathometer           ',...
'                   numb_pts          Number of points in the profile     n/a',...
'                   press_max         Deepest point (pressure) of the profile  decibars',...
'                   press             Pressure                            decibars (m), with 1 dbar',...
'                                                                         intervals standard',...
'                   temp              Temperature                         Degrees centigrade',...
'                   sal               Salinity, derived from Temp and     psu',...
'                                     Cond. measurements using SeaBird software',...
'                   sigma_t_ctd       Density, derived                    sigma-theta units',...
'                   depth             Sample depth, derived               meters',...
'                   potemp_ctd        Potential Temperature, derived      deg C',...
'                   cond_ctd          Conductivity                        Siemens/m',...
'                   light_tran        Percent Light Transmission          n/a',...
'                   fluor             fluorescence, chlorophyll           microgram/liter (units depend',...
'                                     concentration                       on sensor)',...
'                   par_d             upwelling (lowerface) photosynthe-  micro Einsteins per meters^2',...
'                                     tically active radiation            per second',...
'                                     (400-700nm)',...
'                   o2                Dissolved Oxygen derived from       milliliters/liter',...
'                                     oxygen conductivity and temperature ',...
'                                     measurements using SeaBird software',...
'                   bvfq              Brunt-Vaisala Frequency (N^2)       1/sec-sq',...
'                                     , Higher values suggest increased ',...
'                                     stability',...
'                   sound_vel         Sound Velocity, derived             meters/second',...
'                   ',...
'  Note: The Brunt-Vaisaila Frequency (N-squared) data were reprocessed by Frank Bub with raw data',...
'        calculated over 1 m intervals, rather than smoothed over 5 m bins. The 5 m bins did not work ',...
'        well with inshore profiles. Negative numbers indicate instability. Use data with caution. ');

Comments2 = sprintf('%s\n', ...
'  ',...
' The UNH SBE-25 SeaLogger measures: ',...
'  ',...
'     Temperature (degrees C) with a SeaBird SBE-3F. ',...
'     Conductivity (Siemens/m) with a SeaBird SBE-4C. ',...
'     Pressure (decibars) with a SBE 29 strain gage sensor.',... 
'     Percent light transmission with a Wet Labs CST-126R transmissometer across a 25 cm distance at',...
'     the red light wavelength 660 nm. Data are presented as a percentage relative to pure water. ',...
'     Chlorophyll concentration in micrograms/liter with a Wet Labs WETStar Fluorometer model',...
'     9607003. ',...
'     PAR (photosynthetically active radiation) with a Biospherical QPS-200PD which observes an upper',...
'     hemispherical total irradiance in quanta/sq-cm/sec. ',...
'     Dissolved oxygen with a SBE-23Y (Yellow Springs Instrument) in milliliters/liter. ',...
'  ',...
' During a cast, sensors are flushed with a SBE-5T pump at approximately 25 ml/s. The system samples and',...
' stores all data at 8 Hz (8 samples/ second). Profiling rates should be 20 meters/minute for an average ',...
' of 24 samples/1 m pressure level. Normally only the downcasts are analyzed (unless a problem is noted). ',...
' Sensors are factory calibrated annually. ',...
'  ',...
' Derived data are calculated using Matlab and/or UNH algorithms developed in accordance with standards',...
' prescribed by Fofonoff and Millard, 1983. ',...
'  ',...
' For additional information about the SC9801 cruise see the NOAA Coastal Ocean Program Progress Report',...
' (http://globec.whoi.edu/globec-dir/reports/sc9801/progress_report.html)'); 

Comments4 = sprintf('%s\n', ...
'   ', ...
'    Time_Period_of_Content = ', ...
'         Beginning_Date: Feb. 21, 1998 (1998.14183219) ', ...
'         Ending_Date:    Jun. 02, 1998 (1998.41812215)', ...
'    Spatial_Domain = ', ...
'         Bounding Coordinates: ', ...
'              West Bounding Coordinate: 69.7167 W ', ...
'              East Bounding Coordinate: 69.5615 W ', ...
'              South Bounding Coordinate: 42.6162 N ', ...
'              North Bounding Coordinate: 43.6182 N ', ...
'   ', ...
'    Point_of_Contact = ', ...
'         Address - si: ', ...
'               Jamie Pierson', ...
'               Univ. of Rhode Island',...
'               Graduate School of Oceanography',...
'               Box 200 ',...
'               Narragansett, RI 02882',...
'               USA ', ...
'               Electronic Mail Address:INTERNET > jpierson@gsosun1.gso.uri.edu',...
'               FAX: 401-874-6853',...
'               --------------------------------------',...
'               Ann Bucklin',...
'               OPAL/EOS',...
'               Univ. of New Hampshire',...
'               Durham, NH 03824',...
'               USA',...
'               Electronic Mail Address:INTERNET > acb@kepler.unh.edu',...
'               FAX: 603-862-0243',...
'         Address - globec: ',...
'               Robert Groman',...
'               Swift House MS# 38',...
'               Woods Hole, MA 02543-1127',...
'               USA ',...
'               Electronic Mail Address:INTERNET > rgroman@whoi.edu',...
'               FAX: (508) 457-2169',...
'         Address - dods: ',...
'               Electronic Mail Address:INTERNET > support@unidata.ucar.edu ');

Comments = [Comments1 Comments2 Comments4];