function [argout1, argout2, argout3, argout4, argout5, argout6] = geties(...
          mode, get_ranges, get_dset, get_vars, get_dset_stride, get_num_urls, ...
          get_georange, get_variables, get_archive, whichurl)
%
% 
% GETies   Part of the DODS browse package.
%
% This function is used to get IES (Inverted Echo Sounder) data with depth, time and location
% information displayed. 
%
% The following variables are required in the archive.m file:
%   TimeRange, LatitudeRange, LongitudeRange, DepthRange, DepthUnits, DodsName, 
%   SelectableVariables, OptionalVariables, Acknowledge
%   ** If the 'OptionalVariables' is not applied in your dataset, NaN is acceptable.
% The following variables are optional in the arvhive.m file:
%   Server, TimeName, LatitudeName, LongitudeName, DepthName, SelectableOptional, Data_Use_Policy,
%   DataNull, DataScale, DataRange
%
% For details of the features in this function, see 'getjgsta.m'.
%
%**************************************************************************
%
%

%
% $Log: geties.m,v $
% Revision 1.4  1999/10/28 18:41:48  root
% *** empty log message ***
%
% Revision 1.3  1999/10/27 22:19:03  root
% *** empty log message ***
%
% Revision 1.2  1999/10/27 22:17:12  root
% *** empty log message ***
%
% Revision 1.2  1999/10/08 16:17:06  kwoklin
% Finallize comments and slice time series from GEM output. Modified data
% size calculation to more precise level.                     klee
%
%
% $Id: geties.m,v 1.4 1999/10/28 18:41:48 root Exp $
% klee 10/06/99, slice time series from gem output.
% klee 06/30/99, adopted from getjgsta.m (revision: 1.6) and getrectg.m (revision: 1.11).

% used by DODS browser

%global range_day ranges lyr dset var dset_stride num_urls master_georange
%global archive gui_buttons num_vars num_sets

% used only locally
global Pass_Times Pass_Depths old_var old_dset old_ranges

% explanation:
%
% get_ranges = [WestLon EastLon   -- units: decimal degrees
%           SouthLat NorthLat -- units: decimal degrees
%           MinDepth MaxDepth -- units: meters
%           MinTime  MaxTime]  -- units: decimal years
%
% mode may be 'cat' (Catalogue data holdings) or 'get' (Get Data)
%
% if 'get', will have a second arguement, if 0, eval total size of request
% and return. If 1 or greater, get the data.
%

if exist(get_archive) == 2
  eval(get_archive)
else
  dodsmsg(['Problem reading dataset metadata ' get_archive '.m'])
  return
end


if nargin >= 1

  % initialize return arguments
  argout1 = [];
  argout2 = [];
  argout3 = [];
  argout4 = [];
  argout5 = [];
  argout6 = [];

  % SET UP THE METADATA
  % ************************************************************************
  % Set-up for accessing the FRONTS DODS server:
  % Create  constraint expression form browser input values-
  % date, lat/lon, archive type and depth
  % ************************************************************************

  if strcmp(mode,'cat') 		% 'cat' return catalogue of time value
    
    %catch any unmatched data range
    if(get_ranges(4,1) > TimeRange(2) | get_ranges(4,2) < TimeRange(1))
      dodsmsg(' Requested time range does not overlap data. Please respecify')
      return
    end
    
    %save these values
    old_ranges = get_ranges;
    old_dset = get_dset;
    old_var = get_vars;

    %fill up returned arguments with dummy values to prevent crashes
    num_url = 1;  %set default
    loaddodsbool = 1; %set default 
    times = []; Pass_Times = []; depths = []; Pass_Depths = []; 
    lats = []; lons = []; infotext = [];
    url = '';
    
    if exist('Cat_m_File') == 1 % check if 'Cat_m_File' is a local variable
      if exist(Cat_m_File) == 2 % check if Cat_m_File is a script ...
	eval(['[url,loaddodsbool,infotext,times,Pass_Times,',...
	      'depths,Pass_Depths,lats,lons,num_url] = ', ...
	      Cat_m_File, ...
	      '(get_archive, get_ranges, mode);'])
	argout6 = url;
      else
	dodsmsg(['Unable to find script ' Cat_m_File])
	return
      end
    else
      %for datasets that need only one loaddods call for each 
      % inventory and data search
      str = ['[url,loaddodsbool,infotext,times,Pass_Times,', ...
	    'depths,Pass_Depths,lats,lons,num_url]=', ...
	    URL_m_File,'(get_archive, get_ranges, mode);'];
      eval(str);
      argout6 = url;
    end
    
    %get the inventory explicitly
    if loaddodsbool == 1
      if ~isempty(findstr(url, 'nph-jg'))
        % be sure to use '-F' tag cause jgofs returns string vector
        loaddods('-F',url);
      else
	% added conditional here -- dbyrne 99/10/28
	if ~isempty(url)
	  loaddods(url);
	end
      end
    end

    % Check for Longitude convention used in the browser, need to convert lon < 0
    % to lon+360 when master_georange(1) == 0
    if num_url > 0
      TempLongitude = [];   namebool = 0;
      if ~isempty(deblank(LongitudeName)) & exist(deblank(LongitudeName)) == 1
        TempLongitude = eval(LongitudeName);  namebool = 1;
      elseif ~isempty(lons)
        TempLongitude = lons;
      end
      if ~isempty(TempLongitude)
        if abs(get_ranges(1,1) - get_ranges(1,2)) >= 360
          % the data were not split into 2 fetch args!
          % don't fiddle with them
        else
          if get_georange(1) == -180
            TempLongitude = (TempLongitude >=180).*(TempLongitude-360)+ ...
		            (TempLongitude < -180).*(TempLongitude+360)+ ...
		            (TempLongitude >= -180 & TempLongitude < 180).*TempLongitude;
          elseif get_georange(1) == 0
            TempLongitude = (TempLongitude >= 360).*(TempLongitude-360)+ ...
		            (TempLongitude < 0).*(TempLongitude+360)+ ...
		            (TempLongitude >= 0 & TempLongitude < 360).*TempLongitude;
          end
          if namebool == 1
            eval([LongitudeName '= TempLongitude; clear TempLongitude'])
          else
            lons = TempLongitude; clear TempLongitude;
          end
        end
      end % end of if ~isempty(TempLongitude)
    end % end of if num_url > 0

    % FIXED so that if there are routines with names in TimeName, they
    % are not accidentally evaluated -- dbyrne 99/06/01
    %argout1, 2, 3, 4, 5, 6 are x, y, z, t, n, URL, respectively
    if isempty(times) & exist(TimeName)==1, argout4 = eval(deblank(TimeName)); 
    elseif ~isempty(times), argout4 = times; else argout4 = []; end
    if isempty(depths) & exist(DepthName)==1, argout3 = eval(deblank(DepthName)); 
    elseif ~isempty(depths), argout3 = depths; else argout3 = []; end
    if isempty(lats) & exist(LatitudeName)==1, argout2 = eval(deblank(LatitudeName));
    elseif ~isempty(lats), argout2 = lats; else argout2 = []; end
    if isempty(lons) & exist(LongitudeName)==1, argout2 = eval(deblank(LongitudeName));
    elseif ~isempty(lons), argout1 = lons; else argout1 = []; end

    % indicate if there really is any data 
    if any(length(argout1) > 0 | length(argout2) > 0 | ...
      length(argout3) > 0 | length(argout4) > 0)
      %argout5 = max(length(argout1),1) * max(length(argout2),1) * ...
      %	  max(length(argout3),1) * max(length(argout4),1);
      %We don't want to loop through it
      if argout4 > 1e-10
        % jg server returns a big negative number if any data is null
        argout5 = num_url;
      else
        argout5 = 0;
      end
    else
      argout5 = 0;
    end
    
    % display any extra info related to station/inst/cruiseid
    % work around until character variables are available    klee 03/99
    if exist('infotext') == 1 & ~isempty(infotext)
      % display only during first request
      if whichurl == 1
	dodsmsg(infotext);
      end
    end
      
    return                              % catalog query ('cat') mode over

  else                                  % get data w/o catalog query
    %****************************************************************************
    %Get Data:  Requires multiaccess to server for multiple variables through loops
    % * FRONTS dataset has only one access to the server * 
    %****************************************************************************

    % fill up returned arguments with dummy values to prevent crashes
    %get_num_urls = 1;  loaddodsbool = 1; %set default 
    %times = []; Pass_Times = []; depths = []; Pass_Depths = []; 
    aetbool = 0; stbool = 0; svanbool = 0;

    %Before going to get, check first if the data ranges has changed, second if the 
    %size of the data reqested is larger than the check_level in browse.m

    for i = 1:size(get_variables,1)
      getv = deblank(get_variables(i,:));
      if strcmp(getv, 'Acoustic_Echo_Time')
        aetbool = 1;
      elseif strcmp(getv, 'Sea_Temp')
        stbool = 1;
      elseif strcmp(getv, 'Specific_Vol_Anomaly')
        svanbool = 1;
      end
    end
    if isempty(old_var) | isempty(old_dset) | isempty(old_ranges)
      [x,y,z,t,n,URL] = geties('cat',get_ranges, get_dset, get_vars, ...
          get_dset_stride, get_num_urls, get_georange, get_variables, get_archive);
      if (stbool == 1 | svanbool == 1) & aetbool == 0
        if any(Pass_Times(3:size(Pass_Times,1)) >= 9)
          if maxtr < 1993.52876712329 | mintr > 1995.86849315069
            dodsmsg('This request generates no model output based on the time range you selected.');
            get_num_urls = 0;
          end
        elseif (maxtr >= 1993.52876712329 & maxtr < 1993.83287671233) | mintr > 1995.86849315069
          dodsmsg('This request generates no model output based on the time range you selected.');
          get_num_urls = 0;
        else
          get_num_urls = n;
        end
      elseif aetbool == 1
        get_num_urls = n;
      end
    end
    if size(get_vars) ~= size(old_var) | (get_dset ~= old_dset) | ...
          any(any(get_ranges ~= old_ranges))
      [x,y,z,t,n,URL] = geties('cat',get_ranges, get_dset, get_vars, ...
          get_dset_stride, get_num_urls, get_georange, get_variables, get_archive);
      if (stbool == 1 | svanbool == 1) & aetbool == 0
        if any(Pass_Times(3:size(Pass_Times,1)) >= 9)
          if maxtr < 1993.52876712329 | mintr > 1995.86849315069
            dodsmsg('This request generates no model output based on the time range you selected.');
            get_num_urls = 0;
          end
        elseif (maxtr >= 1993.52876712329 & maxtr < 1993.83287671233) | mintr > 1995.86849315069
          dodsmsg('This request generates no model output based on the time range you selected.');
          get_num_urls = 0;
        else
          get_num_urls = n;
        end
      elseif aetbool == 1
        get_num_urls = n;
      end
    end

    if get_num_urls > 0
      %  The browser always sets the longitude range to go from -180 to 180.  Need
      %  to find out how the data set specifies the longitude range: -180 to 180 or
      %  0 to 360 and set up start and end longitudes accordingly. If the range
      %  selected in the browser is between 0 and 180 it does not matter.

      %  add new lat/lon code here
     
      if strcmp(mode, 'datasize')

        %Eval total size of data requested. If larger than check_level, warning is issued.
        %[datasize, nurls]=getxxx('datasize')
	argout2 = get_num_urls;

        % each gem file output contains 1.12 MB (total of 744 days) of data
        % each echo_time output contains about 0.02 MB of data (total of 3441 elements)
        % estimate size = (stations) * (gem output + echo_time output)
        mint = Pass_Times(1);  maxt = Pass_Times(2);
        miny = floor(mint);  mind = (mint - miny) * 365;
        maxy = floor(maxt);  maxd = (maxt - maxy) * 365;
        if (miny == maxy), days = maxd - mind; else, days = (365-mind)+(maxy-miny-1)*365+maxd; end
        % because model covers only portions of the whole period
        if (days > 744), gdays = 744; else, gdays = days; end  
        argout1 = (size(Pass_Times,1)-2) * (1.2*(gdays/(744) + 0.02*(days*4/3441)));

        return
	
      else
 
        %Most The followings are added from getrectg.m.
        %get selected variables and match those to variablelist (DodsName) 
        %and serverlist (Server)
        geturlbool = 0; stbool = 0; svanbool = 0;
        whichvariables = []; whichinst = [];
        whichinst = Pass_Times(3:size(Pass_Times,1),:);
        tmpwhichinst = reshape(whichinst, 1, size(whichinst,1));
        lat = []; lon = []; depth = [];
        InstLat = [32.5865; 32.4165; 32.2506; 32.0836; 31.5019; 31.0046; 30.0017; 27.9967; 25.0033];
        InstLon = [133.204; 133.301; 133.385; 133.482; 133.799; 134.065; 134.598; 135.618; 137.053];
        InstDep = [830; 960; 1190; 2020; 4880; 4450; 4630; 5270; 5050];
        InstNo = ['01';'02';'03';'04';'06';'07';'08';'09';'10'];
        instno = [1;2;3;4;6;7;8;9;10];
        lat = InstLat(whichinst);
        lon = InstLon(whichinst);
        depth = InstDep(whichinst);
        inst = instno(whichinst(1:size(whichinst,1)));
        for i = 1:size(get_variables,1)
	  for j = 1:size(SelectableVariables,1)
            tmpgetvar = deblank(get_variables(i,:));
	    if strcmp(tmpgetvar, deblank(SelectableVariables(j,:)))
	      whichvariables = [whichvariables tmpwhichinst+(j-1)*9];
              if strcmp(tmpgetvar, 'Acoustic_Echo_Time')
                geturlbool = 1;
              elseif strcmp(tmpgetvar, 'Sea_Temp')
                stbool = 1;
              elseif strcmp(tmpgetvar, 'Specific_Vol_Anomaly')
                svanbool = 1;
              end
	    end
	  end
        end
        if ~isempty(whichvariables)
	  variablelist = DodsName(whichvariables,:); 
          %The additional DodsName vars than SelectableVariables is taken care here.            klee 03/99
          %set extra to 0 if no addition station/inst/cruiseid/cast info need to be returned from loaddods
          extra = 0;
          nvars = size(SelectableVariables,1);
          nvard = size(DodsName,1);
	  serverlist = Server; 
        else
	  dodsmsg('Geties: No variables were selected!')
        end


        % construct and evaluate URL(s)
        VERSION = version; VERSION = str2num(VERSION(1));
        tmpvariablelist = []; tmpserverlist = []; tmpvarlist = []; tmpserlist = [];
        tmpvariablelist = str2mat(TimeName,variablelist);
        if geturlbool == 1
          % if acoustic echo time is requested ....
          for i = 1:size(tmpvariablelist,1)
              if abs(tmpvariablelist(i,1)) ~= 32
                  tmpvarlist = [tmpvarlist; tmpvariablelist(i,:)];
              end
          end
	  tmpwhichvariables = [1 whichvariables+4];
          tmpserverlist = str2mat(TimeName,serverlist);
	  % there will be only one URL.  Initialize it.
	  iURL = '';
          % return the URL to be displayed by the browser. D.B. 98/4/5
	  eval([ '[iURL,loaddodsbool,infotext] =', URL_m_File, '(get_archive, get_ranges, mode,', ...
		 'tmpvarlist, serverlist, Pass_Times, Pass_Depths, whichurl);'])
	  if ~isempty(iURL)
	    argout5 = iURL;
	    loaddods(iURL);
	  end
        end  % end of geturlbool == 1
        avarst = []; avarst_error = []; avarsvan = []; svarsvan_error = []; 
        pressure = []; modeltime = []; modeltime_10 = []; 
        tmpavarst = []; tmpavarst_error = []; tmpavarsvan = []; tmpavarsvan_error = []; 
        tmppressure = []; tmpmodeltime = []; tmptmpmodeltime = [];
        stabool = 0; 
        % If Sea_Temp/SVAN is requested ....
        % We need also to calculate the time range and slice the data,
        % or matlab would go out of memory for the whole time period for all stations.
        mint = Pass_Times(1);  maxt = Pass_Times(2);
        minyear = floor(mint);   maxyear = floor(maxt);
        minday = (mint-minyear)*365; maxday = (maxt-maxyear)*365;
        if minyear == 1993, minday = minday - 365;
        elseif minyear == 1995, minday = minday + 365; end
        if maxyear == 1993, maxday = maxday - 365;
        elseif maxyear == 1995, maxday = maxday + 365; end
        if minday <= -61
          minindex = 1;
        else
          minindex = floor(minday) + 61 + 1;
        end
        if maxday >= 682
          maxindex = 744;
        else
          maxindex = ceil(maxday) + 61 + 1;
        end
        magic = [];  magicname = '';
        if stbool == 1 
          % if sea temperature is requested, call apply_gem and make up the returned variables.
          disp('Applying GEM (Gravest Empirical Mode) technique to retrieve temperature, please wait ....');
          varname = 'Sea_Temp';
          for i = 1:size(whichinst,1)
            if whichinst(i) == 9
              if minday > -172
                minindex_10 = floor(minday) + 172 + 1;
              else
                minindex_10 = 1;
              end
              if maxday <= 126
                maxindex_10 = ceil(maxday) + 172 + 1;
              else
                maxindex_10 = 299;
              end
              if maxindex_10 >= 1 & minindex_10 <= 299
                stabool = 1;
              else
                magic = [magic instno(whichinst(i))];
                modeltime_10 = [];
              end
            else
              if maxindex >= 1 & minindex <= 744
                stabool = 1;
              else
                magic = [magic instno(whichinst(i))];
                tmptmpmodeltime = [];
              end
            end
            tmpvarname = []; tmpvarerror = [];
            if stabool == 1
              str=sprintf('%s%i%s','apply_gem(',whichinst(i),',''t'')');
              disp(str);
              [tmpavarst, tmpavarst_error, tmppressure, tmpmodeltime] = apply_gem(whichinst(i),'t');
              tmpvarname = [varname, '_inst', InstNo(whichinst(i),:)];
              tmpvarerror = [varname, '_Error_inst', InstNo(whichinst(i),:)];
              if whichinst(i) == 9
                modeltime_10 = tmpmodeltime(minindex_10:maxindex_10);
                eval([tmpvarname ' = tmpavarst(:,minindex_10:maxindex_10);']);
                eval([tmpvarerror ' = tmpavarst_error(:,minindex_10:maxindex_10);']);
              else
                tmptmpmodeltime = tmpmodeltime(minindex:maxindex);
                eval([tmpvarname ' = tmpavarst(:,minindex:maxindex);']);
                eval([tmpvarerror ' = tmpavarst_error(:,minindex:maxindex);']);
              end
            end
          end  % end of for loop
          pressure = tmppressure;
          modeltime = tmptmpmodeltime;
        end  % end of if stbool == 1
        if ~isempty(magic), magicname = [magicname, varname]; end
        stabool = 0;  magic = [];
        if svanbool == 1
          % if svan is requested, call apply_gem and make up the returned variables.
          disp('Applying GEM (Gravest Empirical Mode) technique to retrieve specific volumn anomaly, please wait ....');
          varname = 'Svan';
          for i = 1:size(whichinst,1)
            if whichinst(i) == 9
              if minday > -172
                minindex_10 = floor(minday) + 172 + 1;
              else
                minindex_10 = 1;
              end
              if maxday <= 126
                maxindex_10 = ceil(maxday) + 172 + 1;
              else
                maxindex_10 = 299;
              end
              if maxindex_10 >= 1 & minindex_10 <= 299
                stabool = 1;
              else
                magic = [magic instno(whichinst(i))];
                modeltime_10 = [];
              end
            else
              if maxindex >= 1 & minindex <= 744
                stabool = 1;
              else
                magic = [magic instno(whichinst(i))];
                tmptmpmodeltime = [];
              end
            end
            if stabool == 1
              str=sprintf('%s%i%s','apply_gem(',whichinst(i),',''s'')');
              disp(str);
              [tmpavarsvan, tmpavarsvan_error, tmppressure, tmpmodeltime] = apply_gem(whichinst(i),'s');
              tmpvarname = [varname, '_inst', InstNo(whichinst(i),:)];
              tmpvarerror = [varname, '_Error_inst', InstNo(whichinst(i),:)];
              if whichinst(i) == 9
                modeltime_10 = tmpmodeltime(minindex_10:maxindex_10);
                eval([tmpvarname ' = tmpavarsvan(:,minindex_10:maxindex_10);']);
                eval([tmpvarerror ' = tmpavarsvan_error(:,minindex_10:maxindex_10);']);
              else
                tmptmpmodeltime = tmpmodeltime(minindex:maxindex);
                eval([tmpvarname ' = tmpavarsvan(:,minindex:maxindex);']);
                eval([tmpvarerror ' = tmpavarsvan_error(:,minindex:maxindex);']);
              end
            end
            tmpvarname = []; tmpvarerror = [];
          end 
          if isempty(pressure) 
            pressure = tmppressure;
            if isempty(modeltime)
              modeltime = tmptmpmodeltime;
            end
          end
        end  % end of if svanbool == 1
        clear tmpavarst tmpavarst_error tmpavarsvan tmpavarsvan_error tmptmpmodeltime tmppressure;
        % Display deselection message for time out of ranges of model output.
        if ~isempty(magic)
          if ~isempty(magicname)
            magicname = [magicname, ' and ', varname];
          else
            magicname = [magicname, varname];
          end
        end
        if exist('magic') == 1 & ~isempty(magic)
          magicm = '';
          for i = 1:size(magic,2)
            if i < size(magic,2), magicm = sprintf('%s%2d%s',magicm,magic(i),', '); 
            else, magicm = sprintf('%s%2d',magicm,magic(i)); end
          end
          infotext = sprintf('%s%s%s%s\n','Time selected is out of range of the model output ',...
                             'of station(s). ',magicname,'  for station ',magicm,' is(are) deselected!');
          dodsmsg(infotext);
        end

        % add returned OptionalVariables, if any, to variablelist and increment whichvariables
        % based on the order of OptionalVariables
        % record tag as the final number of whichvariables before adding optional variables
        tag = whichvariables(size(whichvariables,2));
        % and size of whichvariables
        tagatsize = size(whichvariables,2);
        if exist('OptionalVariables') == 1 & ~isnan(OptionalVariables)          
          for i = 1:size(OptionalVariables,1)
            if exist(deblank(OptionalVariables(i,:))) == 1 & ~isempty(eval(deblank(OptionalVariables(i,:))))
              % indicate it has been returned to this workspace in loaddods call
              extra = extra + 1;
              variablelist = str2mat(variablelist, OptionalVariables(i,:));
              whichvariables = [whichvariables tag+i];
            end
          end
        end

        % Check for Longitude convention used in browser, need to convert lon < 0
	% to lon+360 when get_georange(1) == 0
        % Adopted from old version of getrectg, here multiple lonname is allowed. klee 07/07/99
        TempLongitude = [];
        if ~isempty(deblank(LongitudeName(1,:)))
          if exist(deblank(LongitudeName(1,:))) == 1
            lonsize = 0;
            lonsize = size(LongitudeName,1);
            str1 = sprintf('%s%s%s','(TempLongitude >=180).*(TempLongitude-360)+', ...
		'(TempLongitude < -180).*(TempLongitude+360)+', ...
	        '(TempLongitude >= -180 & TempLongitude < 180).*TempLongitude');
            str2 = sprintf('%s%s%s','(TempLongitude >= 360).*(TempLongitude-360)+', ...
		'(TempLongitude < 0).*(TempLongitude+360)+', ...
		'(TempLongitude >= 0 & TempLongitude < 360).*TempLongitude');
            if lonsize == 1
              TempLongitude = eval(deblank(LongitudeName));
              if abs(get_ranges(1,1) - get_ranges(1,2)) < 360
                if get_georange(1) == 0
                  eval(['TempLongitude =', str1, ';'])
                elseif get_georange(1) == 0
                  eval(['TempLongitude =', str2, ';'])
                end
              end  
              eval([LongitudeName '= TempLongitude; clear TempLongitude'])
            elseif lonsize > 1
              for i = 1:lonsize
                TempLongitude = eval(deblank(LongitudeName(i,:)));
                if abs(get_ranges(1,1) - get_ranges(1,2)) < 360
                  if get_georange(1) == -180
                    eval(['TempLongitude =', str1, ';'])
                  elseif get_georange(1) == 0
                    eval(['TempLongitude =', str2, ';'])
                  end
                end
                eval([LongitudeName(i,:) '= TempLongitude; clear TempLongitude;'])
              end  % end of for loop
            end  % end of if lonsize == 1, elseif lonsize > 1
          end  % end of exist
        end  % end of ~isempty

        % now make up a list of all returned variables
	% (above list plus time, longitude, latitude, depth),
	% evaluate their sizes, scale them and convert nulls to NaNs.
	% this has to be a temporary variable list -- 'variablelist'
	% is still in use
        tmpwhichvariables = []; tmpsize = [];
	tmpvariablelist = str2mat(TimeName,LongitudeName,LatitudeName, ...
	    DepthName, variablelist);       
	tmpwhichvariables = [1 2 3 4 whichvariables+4];
        tmpsize = size(tmpwhichvariables,2);
	for i = 1:size(tmpvariablelist,1)
	  tmpname = deblank(tmpvariablelist(i,:));
	  if VERSION < 5 % fix v4 bug
	    if size(tmpname,2) > 19
	      tmpname = tmpname(1:19);
	    end
	  end
	  if exist(tmpname) == 1
            tmpout = eval(tmpname);
	    % make a temporary variable to work with
	    sizes(i,:) = size(tmpout);
	    if exist('DataNull') == 1
	      if ~isnan(DataNull(tmpwhichvariables(i)))
		j = find(tmpout == DataNull(tmpwhichvariables(i)));
		tmpout(j) = NaN*j;
	      else
		% do nothing because null values are already NaNs
	      end
	    else
	      % if we have no defined null, do nothing
	      % we used to do this!: (bad, bad)
	      % j = find(tmpout < -1.0e+33);
	      % tmpout(j) = NaN*j;
	    end
	    % stack data in a column and scale it if possible
	    if exist('DataScale') == 1
              %DataScale now contains all the variables that
              %need to be returned   klee 04/01/99
              if ~isnan(OptionalVariables) & size(DataScale,1) ~= size(DodsName,1)+size(OptionalVariables,1)+4
                dodsmsg(['Error is in ' get_archive '.m'])
	      	argout1 = [argout1; tmpout(:)];
              elseif isnan(OptionalVariables) & size(DataScale,1) ~= size(DodsName,1)+4
                dodsmsg(['Error is in ' get_archive '.m'])
	      	argout1 = [argout1; tmpout(:)];
              else
		if ~isnan(DataScale(tmpwhichvariables(i),1))
		  argout1 = [argout1; DataScale(tmpwhichvariables(i),1) + ...
                	  tmpout(:)*DataScale(tmpwhichvariables(i),2)];
	   	else % scale exists but is a nan -- don't scale
		  argout1 = [argout1; tmpout(:)];
	        end
              end
	    else % there is no DataScale
	      argout1 = [argout1; tmpout(:)];
	    end
	  else % the supposedly returned variable DOES NOT EXIST 
	    % in this workspace.  Put in an empty placeholder.
	    if ~isempty(tmpname)
	      eval([tmpname '= [];'])
	    end
	    sizes(i,:) = [0 0];
	  end
	end

	% now convert variablelist to user-friendly names
        names = str2mat('Time','Longitude','Latitude','Depth');
        if extra > 0
          nvarw = size(whichvariables,2);
          %names = str2mat(TimeName, LongitudeName, LatitudeName, DepthName);
          for i = 1 : nvarw-extra
            names = str2mat(names, DodsName(whichvariables(i),:));
          end
          if exist('OptionalVariables') == 1 & ~isnan(OptionalVariables) 
            if exist('SelectableOptional') == 1 & ~isnan('SelectableOptional')
              %if there is any optional variables associated with selected variables
              whichop = whichvariables(:,tagatsize+1:nvarw);
              if ~isempty(whichop)
                names = str2mat(names, SelectableOptional(whichop(:)-tag,:));
              end
            end
          end
        else
          %names = str2mat(TimeName, LongitudeName, LatitudeName, DepthName, ...
          %  SelectableVariables(whichvariables,:));
          names = str2mat(names, DodsName(whichvariables,:));
        end

        URL = argout5;

        argout2 = sizes;
        argout3 = names;
        argout4 = tmpwhichvariables;
        % Here, make up for empty URL if only sea_temp/svan is requested.
        if geturlbool == 1
          argout5 = URL;
        else
          argout5 = 'applying GEM program';
        end

	return
      end % /* end of strcmp(mode, 'datasize') */
    end % /* end of if num_urls > 0 */
  end % /* end of strcmp(mode, 'cat') */
end % /* end of if nargin >= 1 */
