%
% The Reynolds monthly climatology. This dataset is stored at URI.
% $Id: reyclim.m,v 1.6 1999/09/02 18:27:31 root Exp $

% $Log: reyclim.m,v $
% Revision 1.6  1999/09/02 18:27:31  root
% *** empty log message ***
%
% Revision 1.6  1999/07/21 15:35:54  dbyrne
%
%
% Corrected language in Acknowledgements.  --dbyrne 99/07/21
%
% Revision 1.5  1999/07/02 16:25:54  kwoklin
% Move server to 'maewest'.    klee
%
% Revision 1.4  1999/05/21 16:25:05  kwoklin
% Add 'Acknowledge' for browser v.3.0.0. Update dods support address.   klee
%
% Revision 1.3  1999/05/13 03:09:55  dbyrne
%
%
% Added Acknowledge and Data_Use_Policy to archive.m.  Fixed getxxx functions
% to use dodsmsg instead of stdout for errors/info.  Made ChangeLog so that it's
% in Emacs format.  All changes for release 3.0.0 -- dbyrne 99/05/12
%
% Revision 1.5  1999/05/13 01:24:18  root
% Added Acknowledge and Data_Use Policy.  Fixed some bugs.  Changed any
% messages to use to use 'dodsmsg' script instead of just displaying to stdout.
%
% Revision 1.4  1999/03/04 13:13:34  root
% All changes since AGU week.
%
% Revision 1.2  1998/12/15 19:10:44  jimg
% Modified 'DataName' to include variable type information.
%
% Revision 1.1  1998/11/18 19:35:19  dbyrne
%
%
% Used to be reynolds.m
%
% Revision 1.3  1998/11/18 12:01:06  root
% Changed dataset names to be a little more clear.
%
% Revision 1.2  1998/11/18 11:57:26  root
% Changed time range to span entire time line.
%
% Revision 1.1  1998/11/18 11:49:11  root
% Changed name from reynolds.m to emphasize that this is a climatology.
%
% Revision 1.15  1998/11/18 11:47:33  root
% fixing documentation
%
% Revision 1.14  1998/11/18 11:44:19  root
% fixing documentation
%
% Revision 1.13  1998/11/05 16:01:55  root
% Changed LonVector and LatVector to be used if no Lon returned and tried the update function.
% DataScale and DataNull should now be optional!
%
% Revision 1.7  1998/09/14 01:32:57  dbyrne
% Elminated an inconsistency whereby the depth variable was not scaled
% and had no DataNull etc.  Added check for empty variables to plotscript.m
%
% Revision 1.12  1998/09/13 19:21:25  root
% Eliminated an inconsistency in DataScale, DataRange, and DataNull, that
% Depth was not included!
%
% Revision 1.11  1998/09/12 10:33:20  root
% Fixing up. This was broken.
%
% Revision 1.10  1998/09/11 18:03:12  dbyrne
% undid latitude range swap!
%
% Revision 1.9  1998/09/11 08:16:10  dbyrne
% Longitude ranges were messed up in every archive.m file except the
% two I wrote myself.  To eliminate future confusion, 'LLon' 'Llat',
% 'Rlon' and 'Ulat' etc are being eliminated in favor of two-component
% vectors LonRange LatRange TimeRange DepthRange.
%
% Revision 1.8  1998/09/09 20:12:18  dbyrne
% Changing variable names to stay within 14 characters.
%
% Revision 1.7  1998/09/09 19:42:30  dbyrne
% Found correct URL_m_file and am using it.
%
% Revision 1.6  1998/09/09 16:10:28  dbyrne
% Fixed numerous small bugs.
%
% Revision 1.5  1998/09/09 15:04:31  dbyrne
% Eliminating all global variables.
%
% Revision 1.4  1998/09/09 07:57:39  dbyrne
% replaced Data_Scale with DataScale, Data_Null with DataNull, and Data_Range
% with DataRange for consistency with other variables in the archive.m files.
%
% Revision 1.3  1998/09/09 07:40:23  dbyrne
% Replaced getrectangular with getrectg
%
% Revision 1.2  1998/09/09 07:34:23  dbyrne
% Eliminating ReturnedVariables
%
% Revision 1.1  1998/05/17 14:18:12  dbyrne
% *** empty log message ***
%
% Revision 1.5  1998/01/14 17:19:01  jimg
% Points to URI monthly dataset.
%
% Revision 1.4  1998/01/14 01:13:43  jimg
% Removed conflicts. Now points back to URI data.
%
% Revision 1.3  1997/12/12 23:53:13  jimg
% Switched to Reynolds dataset at NOAA in Boulder.
%
% Revision 1.2  1997/12/09 07:13:55  jimg
% Version four compatible matrix
%
% Revision 1.1.1.1  1997/09/22 14:13:55  tom
% Imported Matlab GUI sources to CVS

% FUNCTIONS -- REQUIRED
GetFunctionName = 'getrectg';

% FUNCTIONS -- OPTIONAL
URL_m_File = 'uriclurl';
CatalogServer = 'monthly';


% VARIABLES -- OPTIONAL
Server = 'http://maewest.gso.uri.edu/cgi-bin/nph-dsp/dods/sst_clima_reynolds/reynolds_';
Nlon = 360;
Nlat = 180;

% VARIABLES -- REQUIRED
%LonRange = [-179.5 179.5]; % PCC 12/12/98 Changed ranges to correspond to the
%LatRange = [89.5 -89.5];   % edge of a grid element rather than its center.
LonRange = [-180.0 180.0];
LatRange = [90.0 -90.0];
TimeRange = [1800 2000];
DepthRange = [0 0];
DepthUnits = '';
Resolution = 111.0;

%DataName = 'Reynolds Monthly SST Climatology';
                                          % PCC Changed 12/13/98 to regularize names.
DataName = 'SST - Reynolds Monthly Climatology - URI';
LongitudeName = 'lon';
LatitudeName = 'lat';
TimeName = '';
DepthName = '';
SelectableVariables = str2mat('Sea_Temp');
DodsName = 'dsp_band_1';

% don't know if datascale is really correct -- dbyrne, 98/09/12
DataScale = [NaN NaN; NaN NaN; NaN NaN; NaN NaN; -3.0 0.15];
DataNull = [NaN NaN NaN NaN 0];
DataRange = [NaN NaN; NaN NaN; NaN NaN; NaN NaN;  0.0 32.0];

Data_Use_Policy = sprintf('%s%s%s', ...
    'Availability and usage restrictions: ', ...
    'Anonymous ftp at ftp.cdc.noaa.gov ', ...
    '~ftp/Datasets/reynolds_sst');

Acknowledge = sprintf('%s\n\n%s', ...
    [ 'These data were produced by the Coupled Model Project W/NMCx3', ...
      'National Meteorological Center, World Weather Building, Room 807', ...
      ' 5200 Auth Road, Camp Springs, MD 20746 USA', ...
      'The data were provided by the Graduate School of Oceanography at ',...
      'University of Rhode Island ', ...
      '(http://rs.gso.uri.edu/avhrr-archive/archive.html) and accessed via ', ...
      'the Distributed Oceanographic Data System (DODS: ', ...
      'http://www.unidata.ucar.edu/packages/dods).'], ...
    [ 'Citation: Reynolds, R. W. and T. M. Smith (1995). A ',...
      'high-resolution global sea surface ',...
      'temperature climatology.  Journal of Climate 8, 1571--1583. ']);

% COMMENTS
Comments1 = sprintf('%s\n', ...
'                       Reynolds Monthly Climatology', ...
'   ', ...
'     The optimum interpolation (OI) sea surface temperature (SST)',...
'     analysis is produced monthly on a one-degree grid. The analysis',...
'     uses in situ and satellite SST''s plus SST''s simulated by sea-ice',...
'     cover. Before the analysis is computed, the satellite data is',...
'     adjusted for biases using the method of Reynolds (1988) and',...
'     Reynolds and Marsico (1993). A description of the OI analysis can',...
'     be found in Reynolds and Smith (1994).',...
'     ',...
'     The bias correction improves the large scale accuracy of the OI.',...
'     Examples of the effect of recent corrections is given by Reynolds',...
'     (1993). The bias correction does add a small amount of noise in',...
'     time. Most of the noise can be eliminated by using a 1/4-1/2-1/4',...
'     binomial filter in time. The dataset author STRONGLY recommends that',...
'     this filter be applied to the data fields before they are used. An' ,...
'     improved method of correcting the biases is being developed.',...
'     ',...
'     For a complete description of the data as given by the providers',...
'     and references for the papers cited in the description please see',...
'     their information file. The dates used in the netCDF files are',...
'     the dates of the beginning of the average period.');

Comments2 = sprintf('%s\n', ...
'    References: ', ...
'    ', ...
'    Reynolds, R. W. (1988), A real-time global sea surface temperature ', ...
'       analysis.  J. Climate, 1, 75-86. ', ...
'   ', ...
'    Reynolds, R. W. (1993), Impact of Mount Pinatubo aerosols on ', ...
'       satellite-derived sea surface temperatures.  J. Climate 6, ', ...
'       768-774 ', ...
'   ', ...
'    Reynolds, R. and D. C. Marsico (1993), An improved real-time global ', ...
'       sea surface temperature analysis.  Journal of Climate 6, 114-119 ', ...
'   ', ...
'    Reynolds, R. and T. Smith (1994). Improved global sea surface temperature ', ...
'       analyses using optimum interpolation.  Journal of Climate 7, 929--948. ', ...
'    ', ...
'    Reynolds, R. W. and T. M. Smith (1995). A high-resolution global sea surface ',...
'       temperature climatology.  Journal of Climate 8, 1571--1583. ');


Comments3 = sprintf('%s\n', ...
'    ', ...
'    Units:  Degrees Centigrade ', ...
'    Resolution: .15 deg. C ', ...
'    Accuracy: ', ...
'    Time_Period_of_Content = ', ...
'         Beginning_Date:1990', ...
'         Ending_Date: present', ...
'    Spatial_Domain = ', ...
'         Bounding Coordinates: ', ...
'              West Bounding Coordinate:-179.5 ', ...
'              East Bounding Coordinate:179.5 ', ...
'              South Bounding Coordinate:-89.5 ', ...
'              North Bounding Coordinate:89.5 ', ...
'    ', ...
'    Point_of_Contact (Science) = ', ...
'         Address: ', ...
'               Richard W. Reynolds ', ...
'               Climate Modelling Branch W/NP24', ...
'               NCEP/NWS/NOAA ', ...
'               5200 Auth Road, Room 807', ...
'               Camp Springs, Maryland 20746 ', ...
'               USA ', ...
'               Telephone: (301) 763-8000 ext 7580', ...
'         Electronic Mail Address:INTERNET > rreynolds@sun1.wwb.noaa.gov', ...
'    Point_of_Contact = (Data Provision)', ...
'         Address: ', ...
'               Peter Cornillon ', ...
'               Graduate School of Oceanography ', ...
'               University of Rhode Island ', ...
'               South Ferry Road ', ...
'               Narragansett, Rhode Island  02882 ', ...
'               USA ', ...
'         Electronic Mail Address:INTERNET > support@unidata.ucar.edu ');


Comments = [Comments1 Comments2 Comments3]; 
